==> vtk-v4.0.2.zip: vtk-v4.0.2/Common/Testing/Cxx/otherCellTypes.cxx <==
/*==========================================================================

  Program: 
  Module:    otherCellTypes.cxx
  Language:  C++
  Date:      $Date$
  Version:   $Revision$

  ==========================================================================*/

// .NAME 
// .SECTION Description
// this program tests the CellTypes

#include "vtkDebugLeaks.h"

#include "vtkCellTypes.h"
#include "vtkCellType.h"

void Test(ostream& strm)
{
  // actual test
  strm << "Test CellTypes Start" << endl;
  vtkCellTypes *ct = vtkCellTypes::New();
  ct->Allocate();

  ct->InsertCell(0, VTK_QUAD, 0);
  ct->InsertNextCell(VTK_PIXEL, 1);

  vtkUnsignedCharArray *cellTypes = vtkUnsignedCharArray::New();
  vtkIntArray *cellLocations = vtkIntArray::New();

  cellLocations->InsertNextValue (0);
  cellTypes->InsertNextValue(VTK_QUAD);

  cellLocations->InsertNextValue (1);
  cellTypes->InsertNextValue(VTK_PIXEL);

  cellLocations->InsertNextValue (2);
  cellTypes->InsertNextValue(VTK_TETRA);

  ct->SetCellTypes (3, cellTypes, cellLocations);

  ct->GetCellLocation (1);
  ct->DeleteCell(1);

  ct->GetNumberOfTypes();

  ct->IsType(VTK_QUAD);
  ct->IsType(VTK_WEDGE);

  ct->InsertNextType(VTK_WEDGE);
  ct->IsType(VTK_WEDGE);

  ct->GetCellType(2);

  ct->GetActualMemorySize();

  vtkCellTypes *ct1 = vtkCellTypes::New();
  ct1->DeepCopy(ct);

  ct->Reset();
  ct->Squeeze();

  ct1->Delete();
  ct->Delete();
  cellLocations->Delete();
  cellTypes->Delete();
  strm << "Test CellTypes Complete" << endl;
}

int main()
{
  vtkDebugLeaks::PromptUserOff();

  Test(cout);

  return 0;
}

==> vtk-v4.2.6.zip: vtk-v4.2.6/Common/Testing/Cxx/otherCellTypes.cxx <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    otherCellTypes.cxx
  Language:  C++
  Date:      $Date$
  Version:   $Revision$

  Copyright (c) 1993-2002 Ken Martin, Will Schroeder, Bill Lorensen 
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even 
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/

// .NAME 
// .SECTION Description
// this program tests the CellTypes

#include "vtkDebugLeaks.h"

#include "vtkCellTypes.h"
#include "vtkCellType.h"

void TestOCT()
{
  // actual test
  vtkCellTypes *ct = vtkCellTypes::New();
  ct->Allocate();

  ct->InsertCell(0, VTK_QUAD, 0);
  ct->InsertNextCell(VTK_PIXEL, 1);

  vtkUnsignedCharArray *cellTypes = vtkUnsignedCharArray::New();
  vtkIntArray *cellLocations = vtkIntArray::New();

  cellLocations->InsertNextValue (0);
  cellTypes->InsertNextValue(VTK_QUAD);

  cellLocations->InsertNextValue (1);
  cellTypes->InsertNextValue(VTK_PIXEL);

  cellLocations->InsertNextValue (2);
  cellTypes->InsertNextValue(VTK_TETRA);

  ct->SetCellTypes (3, cellTypes, cellLocations);

  ct->GetCellLocation (1);
  ct->DeleteCell(1);

  ct->GetNumberOfTypes();

  ct->IsType(VTK_QUAD);
  ct->IsType(VTK_WEDGE);

  ct->InsertNextType(VTK_WEDGE);
  ct->IsType(VTK_WEDGE);

  ct->GetCellType(2);

  ct->GetActualMemorySize();

  vtkCellTypes *ct1 = vtkCellTypes::New();
  ct1->DeepCopy(ct);

  ct->Reset();
  ct->Squeeze();

  ct1->Delete();
  ct->Delete();
  cellLocations->Delete();
  cellTypes->Delete();
}

int otherCellTypes(int, char *[])
{
  vtkDebugLeaks::PromptUserOff();

  TestOCT();

  return 0;
}
